modes

package
v0.0.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 19, 2024 License: MIT Imports: 11 Imported by: 0

Documentation

Overview

Package modes is responsible for handling database connection type.

Currently, we support following modes: - file - stream - socket (data is not serialized, output is compatible with stream mode output)

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func HandleFileMode

func HandleFileMode(filePath string, engine *engine.DbEngine, evaluate func(sequences *ast.Sequence, engineSQL *engine.DbEngine) string)

HandleFileMode - Handle GO4SQL use case where client sends input via text file

func HandleSocketMode

func HandleSocketMode(port int, engine *engine.DbEngine, evaluate func(sequences *ast.Sequence, engineSQL *engine.DbEngine) string)

HandleSocketMode - Handle GO4SQL use case where client sends input via socket protocol

func HandleStreamMode

func HandleStreamMode(engine *engine.DbEngine, evaluate func(sequences *ast.Sequence, engineSQL *engine.DbEngine) string)

HandleStreamMode - Handle GO4SQL use case where client sends input via stdin

Types

This section is empty.

Jump to