Documentation
¶
Overview ¶
Package modes is responsible for handling database connection type.
Currently, we support following modes: - file - stream - socket (data is not serialized, output is compatible with stream mode output)
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func HandleFileMode ¶
func HandleFileMode(filePath string, engine *engine.DbEngine, evaluate func(sequences *ast.Sequence, engineSQL *engine.DbEngine) string)
HandleFileMode - Handle GO4SQL use case where client sends input via text file
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.