Documentation
¶
Overview ¶
Package parser creates sequences from tokens
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Parser ¶
type Parser struct {
// contains filtered or unexported fields
}
Parser - Contain token that is currently analyzed by parser and the next one. Lexer is used to tokenize the client text input.
func (*Parser) ParseSequence ¶
ParseSequence - Return ast.Sequence (sequence of commands) created from client input after tokenization
Parse tokens returned by lexer to structures defines in ast package, and it's responsible for syntax validation.
Click to show internal directories.
Click to hide internal directories.